You are viewing a plain text version of this content. The canonical link for it is here.
Posted to adffaces-commits@incubator.apache.org by ma...@apache.org on 2006/07/26 21:34:17 UTC

svn commit: r425851 - in /incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test: conf/META-INF/faces-config.xml java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java

Author: matzew
Date: Wed Jul 26 14:34:16 2006
New Revision: 425851

URL: http://svn.apache.org/viewvc?rev=425851&view=rev
Log: (empty)

Modified:
    incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/conf/META-INF/faces-config.xml
    incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/conf/META-INF/faces-config.xml
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/conf/META-INF/faces-config.xml?rev=425851&r1=425850&r2=425851&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/conf/META-INF/faces-config.xml (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/conf/META-INF/faces-config.xml Wed Jul 26 14:34:16 2006
@@ -148,9 +148,9 @@
   
   <referenced-bean>
     <description>implicit object provided by ADF Faces</description>
-    <display-name>ADF Faces Context</display-name>
+    <display-name>Request Context</display-name>
     <referenced-bean-name>adfFacesContext</referenced-bean-name>
-    <referenced-bean-class>org.apache.myfaces.trinidad.context.AdfFacesContext</referenced-bean-class>
+    <referenced-bean-class>org.apache.myfaces.trinidad.context.RequestContext</referenced-bean-class>
   </referenced-bean>
 
   <referenced-bean>

Modified: incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java
URL: http://svn.apache.org/viewvc/incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java?rev=425851&r1=425850&r2=425851&view=diff
==============================================================================
--- incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java (original)
+++ incubator/adffaces/branches/matzew-repackaging-trinidad/plugins/maven-faces-plugin/src/test/java-templates/org/apache/myfaces/trinidad/component/UIXCommandTemplate.java Wed Jul 26 14:34:16 2006
@@ -24,7 +24,7 @@
 import javax.faces.event.FacesEvent;
 import javax.faces.event.PhaseId;
 
-import org.apache.myfaces.trinidad.context.AdfFacesContext;
+import org.apache.myfaces.trinidad.context.RequestContext;
 import org.apache.myfaces.trinidad.event.LaunchEvent;
 import org.apache.myfaces.trinidad.event.LaunchListener;
 import org.apache.myfaces.trinidad.event.ReturnEvent;
@@ -97,12 +97,12 @@
   public void broadcast(FacesEvent event) throws AbortProcessingException
   {
     // Perform special processing for ActionEvents:  tell
     // the AdfFacesContext to remember this command instance
     // so that the NavigationHandler can locate us to queue
     // a LaunchEvent.
     if (event instanceof ActionEvent)
     {
-      AdfFacesContext afContext = AdfFacesContext.getCurrentInstance();
+      RequestContext afContext = RequestContext.getCurrentInstance();
       afContext.getDialogService().setCurrentLaunchSource(this);
 
       try
@@ -97,12 +97,12 @@
   {
     // Perform special processing for ActionEvents:  tell
-    // the AdfFacesContext to remember this command instance
+    // the RequestContext to remember this command instance
     // so that the NavigationHandler can locate us to queue
     // a LaunchEvent.